@@ -515,10 +515,10 @@ private:
     QString             _serialized;
 
 public:
-    softstoreKeyStoreEntryContext(const KeyBundle &     key,
+    softstoreKeyStoreEntryContext(const KeyBundle      &key,
                                   const SoftStoreEntry &entry,
-                                  const QString &       serialized,
-                                  Provider *            p)
+                                  const QString        &serialized,
+                                  Provider             *p)
         : KeyStoreEntryContext(p)
     {
         _item_type  = KeyStoreEntry::TypeKeyBundle;
@@ -742,7 +742,7 @@ public:
         list += _last_id;
 
         QCA_logTextMessage(
-            QString::asprintf("softstoreKeyStoreListContext::keyStores - return out.size()=%d", list.size()),
+            QString::asprintf("softstoreKeyStoreListContext::keyStores - return out.size()=%d", int(list.size())),
             Logger::Debug);
 
         return list;
@@ -760,7 +760,7 @@ public:
         }
 
         QCA_logTextMessage(
-            QString::asprintf("softstoreKeyStoreListContext::entryList - return out.size()=%d", list.size()),
+            QString::asprintf("softstoreKeyStoreListContext::entryList - return out.size()=%d", int(list.size())),
             Logger::Debug);
 
         return list;
@@ -957,7 +957,7 @@ private:
             QString::asprintf(
                 "softstoreKeyStoreListContext::_deserializeSoftStoreEntry - return ret=%d chain.size()=%d",
                 ret ? 1 : 0,
-                entry.chain.size()),
+                int(entry.chain.size())),
             Logger::Debug);
 
         return ret;
@@ -1016,7 +1016,11 @@ private:
             QChar c = from[i];
 
             if (c == QLatin1Char('\\')) {
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 2)
+                to += QChar((ushort)QStringView(from).mid(i + 2, 4).toInt(nullptr, 16));
+#else
                 to += QChar((ushort)from.midRef(i + 2, 4).toInt(nullptr, 16));
+#endif
                 i += 5;
             } else {
                 to += c;
