@@ -247,7 +247,7 @@ public Q_SLOTS:
         int                  at = findItem(trackerId);
         if (at == -1)
             return out;
-        Item &                              i    = items[at];
+        Item                               &i    = items[at];
         const QList<KeyStoreEntryContext *> list = i.owner->entryList(i.storeContextId);
         for (int n = 0; n < list.count(); ++n) {
             KeyStoreEntry entry;
@@ -803,7 +803,7 @@ public:
     KeyStoreManager       ksm;
     KeyStoreEntry         entry;
     QString               storeId, entryId;
-    KeyStore *            ks;
+    KeyStore             *ks;
     bool                  avail;
 
     Private(KeyStoreEntryWatcher *_q)
@@ -982,13 +982,13 @@ protected:
         else if (type == WriteEntry) {
             QVariant arg;
             if (wentry.type == KeyStoreWriteEntry::TypeKeyBundle)
-                arg.setValue<KeyBundle>(wentry.keyBundle);
+                arg = QVariant::fromValue<KeyBundle>(wentry.keyBundle);
             else if (wentry.type == KeyStoreWriteEntry::TypeCertificate)
-                arg.setValue<Certificate>(wentry.cert);
+                arg = QVariant::fromValue<Certificate>(wentry.cert);
             else if (wentry.type == KeyStoreWriteEntry::TypeCRL)
-                arg.setValue<CRL>(wentry.crl);
+                arg = QVariant::fromValue<CRL>(wentry.crl);
             else if (wentry.type == KeyStoreWriteEntry::TypePGPKey)
-                arg.setValue<PGPKey>(wentry.pgpKey);
+                arg = QVariant::fromValue<PGPKey>(wentry.pgpKey);
 
             // note: each variant in the argument list is resolved
             //   to its native type.  so even though it looks like
@@ -1010,8 +1010,8 @@ class KeyStorePrivate : public QObject
 {
     Q_OBJECT
 public:
-    KeyStore *                 q;
-    KeyStoreManager *          ksm;
+    KeyStore                  *q;
+    KeyStoreManager           *ksm;
     int                        trackerId;
     KeyStoreTracker::Item      item;
     bool                       async;
@@ -1239,8 +1239,7 @@ QString KeyStore::writeEntry(const KeyBundle &kb)
         d->async_writeEntry(KeyStoreWriteEntry(kb));
         return QString();
     } else {
-        QVariant arg;
-        arg.setValue<KeyBundle>(kb);
+        const auto arg = QVariant::fromValue<KeyBundle>(kb);
         return trackercall("writeEntry", QVariantList() << d->trackerId << arg).toString();
     }
 }
@@ -1251,8 +1250,7 @@ QString KeyStore::writeEntry(const Certificate &cert)
         d->async_writeEntry(KeyStoreWriteEntry(cert));
         return QString();
     } else {
-        QVariant arg;
-        arg.setValue<Certificate>(cert);
+        const auto arg = QVariant::fromValue<Certificate>(cert);
         return trackercall("writeEntry", QVariantList() << d->trackerId << arg).toString();
     }
 }
@@ -1263,8 +1261,7 @@ QString KeyStore::writeEntry(const CRL &crl)
         d->async_writeEntry(KeyStoreWriteEntry(crl));
         return QString();
     } else {
-        QVariant arg;
-        arg.setValue<CRL>(crl);
+        const auto arg = QVariant::fromValue<CRL>(crl);
         return trackercall("writeEntry", QVariantList() << d->trackerId << arg).toString();
     }
 }
@@ -1275,8 +1272,7 @@ QString KeyStore::writeEntry(const PGPKey &key)
         d->async_writeEntry(KeyStoreWriteEntry(key));
         return QString();
     } else {
-        QVariant arg;
-        arg.setValue<PGPKey>(key);
+        const auto arg = QVariant::fromValue<PGPKey>(key);
         return trackercall("writeEntry", QVariantList() << d->trackerId << arg).toString();
     }
 }
